@@ -104,7 +104,7 @@ void AllFilesWidget::SetupTable(int sort_column, Qt::SortOrder sort_order)
         // File Size
         double ffsize = QFile(fullpath).size() / 1024.0;
         total_size += ffsize;
-        QString fsize = QString::number(ffsize, 'f', 2);
+        QString fsize = QLocale().toString(ffsize, 'f', 2);
         NumericItem *size_item = new NumericItem();
         size_item->setText(fsize);
         size_item->setTextAlignment(Qt::AlignRight);
