@@ -29,8 +29,9 @@
 #include <QtWidgets/QDialog>
 #include <QtGui/QStandardItemModel>
 #include <QtCore/QSharedPointer>
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QtWidgets/QMenu>
+#include <QStringList>
 
 #include "ResourceObjects/Resource.h"
 #include "BookManipulation/Book.h"
@@ -39,7 +40,6 @@
 #include "ui_ReportsAllFilesWidget.h"
 
 class QString;
-class QStringList;
 
 class AllFilesWidget : public ReportsWidget
 
