@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2015-2024 Kevin B. Hendricks, Stratford Ontario Canada
 **  Copyright (C) 2012-2013 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012-2013 Dave Heiland
 **
@@ -62,12 +62,13 @@ SpellcheckEditor::SpellcheckEditor(QWidget *parent)
 {
     ui.setupUi(this);
     ui.FilterText->installEventFilter(this);
-
     SetupSpellcheckEditorTree();
     CreateContextMenuActions();
     ConnectSignalsSlots();
     UpdateDictionaries();
     ReadSettings();
+    // first time opening try to select the first row
+    m_SelectRow = 0;
 }
 
 SpellcheckEditor::~SpellcheckEditor()
@@ -350,10 +351,10 @@ void SpellcheckEditor::Refresh(int sort_column, Qt::SortOrder sort_order)
     ui.FilterText->setFocus();
     FilterEditTextChangedSlot(ui.FilterText->text());
 
-    SelectRow(m_SelectRow);
     UpdateSuggestions();
-
     QApplication::restoreOverrideCursor();
+    ui.SpellcheckEditorTree->setFocus();
+    SelectRow(m_SelectRow);
 }
 
 void SpellcheckEditor::UpdateDictionaries()
@@ -419,9 +420,9 @@ void SpellcheckEditor::SelectRow(int row)
         QStandardItem *child = root_item->child(row, 0);
         if (child) {
             QModelIndex index = child->index();
+            ui.SpellcheckEditorTree->setCurrentIndex(child->index());
             ui.SpellcheckEditorTree->setFocus();
             ui.SpellcheckEditorTree->selectionModel()->select(index, QItemSelectionModel::Select | QItemSelectionModel::Rows);
-            ui.SpellcheckEditorTree->setCurrentIndex(child->index());
         }
     }
 
@@ -634,14 +635,8 @@ void SpellcheckEditor::ConnectSignalsSlots()
             this,               SLOT(ChangeState(int)));
     connect(ui.LocaleAwareSort,  SIGNAL(stateChanged(int)),
             this,               SLOT(ChangeState(int)));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(ui.Dictionaries, SIGNAL(activated(const QString &)),
-            this,            SLOT(DictionaryChanged(const QString &)));
-#else
     connect(ui.Dictionaries, SIGNAL(textActivated(const QString &)),
             this,            SLOT(DictionaryChanged(const QString &)));
-#endif
-
     connect(m_FilterSC, SIGNAL(activated()), ui.FilterText, SLOT(setFocus()));
     connect(m_ShowAllSC, SIGNAL(activated()), this, SLOT(toggleShowAllWords()));
     connect(m_AwareSC, SIGNAL(activated()), this, SLOT(toggleLocaleAwareSort()));
