@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2015-2024 Kevin B. Hendricks, Stratford, Ontario, Canada
 **  Copyright (C) 2015-2022 Doug Massay
 **  Copyright (C) 2012-2015 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012      Dave Heiland
@@ -27,8 +27,8 @@
 #ifndef SIGIL_H
 #define SIGIL_H
 
-#include <QtCore/QSharedPointer>
-#include <QtWidgets/QMainWindow>
+#include <QSharedPointer>
+#include <QMainWindow>
 
 #include "ui_main.h"
 #include "BookManipulation/Book.h"
@@ -72,6 +72,7 @@ class ClipsWindow;
 class SelectCharacter;
 class ViewImage;
 class FlowTab;
+class QWidget;
 
 
 /**
@@ -118,9 +119,6 @@ public:
 
     void maybe_fixup_dockwidget_geometry(QDockWidget * widget);
 
-    // returns true if MainWindow is Maximized or is FullScreen
-    bool isMaxOrFull();
-
     /**
      * The book currently being edited.
      *
@@ -154,6 +152,9 @@ public:
     QList <Resource *> GetBookBrowserSelectedResources();
     QList <Resource *> GetValidSelectedHTMLResources();
     QList <Resource *> GetValidSelectedCSSResources();
+    QList <Resource *> GetValidSelectedSVGResources();
+    QList <Resource *> GetValidSelectedJSResources();
+    QList <Resource *> GetValidSelectedMiscXMLResources();
 
     QList <Resource *> GetTabbedHTMLResources();
     QList <Resource *> GetTabbedCSSResources();
@@ -285,9 +286,16 @@ public slots:
     void EditAutomate(const QString &automatefile);
     
     bool StandardizeEpub();
+    bool RebaseManifestIDs();
 
     void CreateEpubLayout();
 
+    void FocusOnCodeView();
+    void FocusOnBookBrowser();
+    void FocusOnPreview();
+    void FocusOnTOC();
+    void FocusOnClips();
+
 signals:
     void SettingsChanged();
 
@@ -313,13 +321,8 @@ protected:
 
 private slots:
 
-    void UpdateLastSizes();
-
-    void RestoreLastNormalGeometry();
-
     bool AddCover();
 
-
     /**
      * Implements New action functionality.
      */
@@ -445,6 +448,11 @@ private slots:
 
     void ClipEditorDialog(ClipEditorModel::clipEntry *clip_entry = NULL);
 
+    /**
+     * Allow Keyboard Focus Navigation to main QDockWidgets
+     */
+    void FocusOn(QWidget* dw=nullptr);
+  
     /**
      * Implements User Guide action functionality.
      */
@@ -690,7 +698,6 @@ private slots:
     void unloadPluginsMenu();
 
 private:
-    void createJumpList();
     void updateToolTipsOnPluginIcons();
     void UpdateClipButton(QAction *ui_action);
     void InsertFiles(const QStringList &selected_images);
@@ -888,6 +895,8 @@ private:
     QStringList m_LastOpenFileWarnings;
     bool m_IsInitialLoad;
 
+    QByteArray m_LastState;
+    
     /**
      * The path to the current file loaded.
      */
@@ -1031,11 +1040,7 @@ private:
     /**
      * Workaround for Qt 4.8 bug, to track the last known window size when not maximized.
      */
-    QByteArray m_LastWindowSize;
-    QByteArray m_LastState;
     bool m_FirstTime;
-    bool m_PendingLastSizeUpdate;
-    bool m_SaveLastEnabled;
 
     QTimer m_PreviewTimer;
 
@@ -1074,6 +1079,8 @@ private:
     bool m_UsingAutomate;
     QStringList m_AutomateLog;
     QString m_AutomatePluginParameter;
+
+    bool m_inShowLastOpenWarnings = false;
     
     /**
      * Holds all the widgets Qt Designer created for us.
