@@ -46,17 +46,10 @@
 #include "ResourceObjects/NCXResource.h"
 #include "ResourceObjects/OPFResource.h"
 #include "ResourceObjects/NavProcessor.h"
+#include "EmbedPython/PythonRoutines.h"
 #include "sigil_constants.h"
 #include "sigil_exception.h"
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
-    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
-#else
-    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
-    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
-#endif
-
 static const QString MEDIA_PLAYBACK_ACTIVE_CLASS = "media:playback-active-class";
 static const QString MEDIA_ACTIVE_CLASS          = "media:active-class";
 static const QString SIGIL_VERSION_META_NAME  = "Sigil version";
@@ -900,7 +893,7 @@ int OPFResource::GetGuideReferenceForResourcePos(const Resource *resource, const
     for (int i=0; i < p.m_guide.count(); ++i) {
         GuideEntry ge = p.m_guide.at(i);
         QString href = ge.m_href;
-        QStringList parts = href.split('#', QT_ENUM_KEEPEMPTYPARTS);
+        QStringList parts = href.split('#', Qt::KeepEmptyParts);
         if (parts.at(0) == href_to_resource_from_opf) {
             return i;
         }
@@ -1054,7 +1047,7 @@ QHash <QString, QString>  OPFResource::GetSemanticCodeForPaths()
     QHash <QString, QString> semantic_types;
     foreach(GuideEntry ge, p.m_guide) {
         QString href = ge.m_href;
-        QStringList parts = href.split('#', QT_ENUM_KEEPEMPTYPARTS);
+        QStringList parts = href.split('#', Qt::KeepEmptyParts);
         QString apath = Utility::URLDecodePath(parts.at(0));
         QString bkpath = Utility::buildBookPath(apath, GetFolder());
         QString gtype = ge.m_type;
@@ -1074,7 +1067,7 @@ QHash <QString, QString>  OPFResource::GetGuideSemanticNameForPaths()
     QHash <QString, QString> semantic_types;
     foreach(GuideEntry ge, p.m_guide) {
         QString href = ge.m_href;
-        QStringList parts = href.split('#', QT_ENUM_KEEPEMPTYPARTS);
+        QStringList parts = href.split('#', Qt::KeepEmptyParts);
         QString gtype = ge.m_type;
         QString apath = Utility::URLDecodePath(parts.at(0));
         QString bkpath = Utility::buildBookPath(apath, GetFolder());
@@ -1602,19 +1595,22 @@ void OPFResource::UpdateManifestProperties(const QList<Resource*> resources)
     }
     foreach(Resource* resource, resources) {
         const HTMLResource* html_resource = static_cast<const HTMLResource *>(resource);
-        // do not overwrite the nav property, it must stay no matter what
-        if (html_resource != m_NavResource) {
-            QString href = Utility::URLEncodePath(GetRelativePathToResource(html_resource));
-            int pos = p.m_hrefpos.value(href, -1);
-            if ((pos >= 0) && (pos < p.m_manifest.count())) {
-                ManifestEntry me = p.m_manifest.at(pos);
-                QStringList properties = html_resource->GetManifestProperties();
-                me.m_atts.remove("properties");
-                if (properties.count() > 0) {
-                    me.m_atts["properties"] = properties.join(QString(" "));
+        QString href = Utility::URLEncodePath(GetRelativePathToResource(html_resource));
+        int pos = p.m_hrefpos.value(href, -1);
+        if ((pos >= 0) && (pos < p.m_manifest.count())) {
+            ManifestEntry me = p.m_manifest.at(pos);
+            QStringList properties = html_resource->GetManifestProperties();
+            // The nav must not lose the nav property
+            if (html_resource == m_NavResource) {
+                if (!properties.contains("nav")) {
+                    properties << "nav";
                 }
-                p.m_manifest.replace(pos, me);
             }
+            me.m_atts.remove("properties");
+            if (properties.count() > 0) {
+                me.m_atts["properties"] = properties.join(QString(" "));
+            }
+            p.m_manifest.replace(pos, me);
         }
     }
     // now add the cover-image properties
@@ -1626,8 +1622,13 @@ void OPFResource::UpdateManifestProperties(const QList<Resource*> resources)
             int pos = p.m_idpos.value(cover_id, -1);
             if (pos >= 0 ) {
                 ManifestEntry me = p.m_manifest.at(p.m_idpos[cover_id]);
+                QString props = me.m_atts.value("properties", "");
+                if (!props.contains("cover-image")) {
+                    props = props + " cover-image";
+                }
+                props = props.simplified();
                 me.m_atts.remove("properties");
-                me.m_atts["properties"] = QString("cover-image");
+                me.m_atts["properties"] = props;
                 p.m_manifest.replace(pos, me);
             }
         }
@@ -1690,6 +1691,7 @@ void OPFResource::SetNavResource(HTMLResource * nav_resource)
 {
     m_NavResource = nav_resource;
     // Make sure the proper nav property is set in the opf manifest
+    // but do not overwrite any other existing properties
     if (m_NavResource) { 
         QWriteLocker locker(&GetLock());
         QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
@@ -1699,7 +1701,13 @@ void OPFResource::SetNavResource(HTMLResource * nav_resource)
         int pos = p.m_hrefpos.value(href, -1);
         if ((pos >= 0) && (pos < p.m_manifest.count())) {
             ManifestEntry me = p.m_manifest.at(pos);
-            me.m_atts["properties"] = QString("nav");
+            QString props = me.m_atts.value("properties", "");
+            if (!props.contains("nav")) {
+                props = props + " nav";
+            }
+            props = props.simplified();
+            me.m_atts.remove("properties");
+            me.m_atts["properties"] = props;
             p.m_manifest.replace(pos, me);
         }
         UpdateText(p);
@@ -1736,3 +1744,13 @@ void OPFResource::SetItemRefLinear(Resource * resource, bool linear)
         UpdateText(p);
     }
 }
+
+
+void OPFResource::RebaseManifestIDs()
+{
+    QWriteLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    PythonRoutines pr;
+    source = pr.RebaseManifestIDsInPython(source);
+    TextResource::SetText(source);
+}
