@@ -39,6 +39,10 @@
 
 #include <QStringList>
 
+// QL1SV() Macro to handle renaming of QLatin1String to QLatin1StringView in Qt6.4+
+#include <QLatin1StringView>
+#define QL1SV(t) QLatin1StringView(t)
+
 class QString;
 
 // These enable us to use constants defined
